% Fltros para la reconstrucción IP. También vale para ENO y SR.
%        preliipvcoefi(nl,nr)
%        Entradas:
%             nl  = numero de nodos a la izquierda de x^{k}_{2*i-1} (sirven valores negativos, i.e. se pueda apliacar para SR)
%             nr  = numero de nodos a la derecha de x^{k}_{2*i-1} (sirven valores negativos, i.e. se pueda apliacar para SR)
%        Salidas:
%             coef= coeficientes buscados (también se muestran por
%             pantalla)
% 
% Autor: José Jaime Noguera   +INFO: www.uv.es/anims/noguera

function coef=preliipvpcoefi(nl,nr)

        %Matriz para valores puntuales IP
        for j=-nl+1:nr
             for i=0:nr+nl-1
              A(j+nl,i+1)=j^i;
             end
        end
        %fin-def matriz
        
        for i=1:nl+nr
           b(i)=(1/2)^(i-1);
        end
        
        format rational
        coef=b*A^(-1)
        format
        
        sprintf('Comienza en f^{k-1}_{i+(%d)} y acaba en f^{k-1}_(i+(%d))',-nl,nr-1)
 